@@ -5,7 +5,11 @@
 
 =head1 支持输出类型
 
-见 Nover::Packer:: 系列模块
+    TXT  : txt形式的小说
+
+    HTML : 网页形式的小说
+
+    WordPress : 将小说发布到WordPress空间
 
 =head1 FUNCTION
 
@@ -26,7 +30,7 @@ use Novel::Robot::Packer::TXT;
 use Novel::Robot::Packer::HTML;
 use Novel::Robot::Packer::WordPress;
 
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 sub init_packer {
     my ( $self, $site , $opt) = @_;
